/// <reference types="node" />
import * as msRest from "@azure/ms-rest-js";
/**
 * @interface
 * An interface representing EntityLabelObject.
 * Defines the entity type and position of the extracted entity within the
 * example.
 *
 */
export interface EntityLabelObject {
    /**
     * @member {string} entityName The entity type.
     */
    entityName: string;
    /**
     * @member {number} startCharIndex The index within the utterance where the
     * extracted entity starts.
     */
    startCharIndex: number;
    /**
     * @member {number} endCharIndex The index within the utterance where the
     * extracted entity ends.
     */
    endCharIndex: number;
    /**
     * @member {string} [role] The role the entity plays in the utterance.
     */
    role?: string;
}
/**
 * @interface
 * An interface representing ApplicationCreateObject.
 * Properties for creating a new LUIS Application
 *
 */
export interface ApplicationCreateObject {
    /**
     * @member {string} culture The culture for the new application. It is the
     * language that your app understands and speaks. E.g.: "en-us". Note: the
     * culture cannot be changed after the app is created.
     */
    culture: string;
    /**
     * @member {string} [domain] The domain for the new application. Optional.
     * E.g.: Comics.
     */
    domain?: string;
    /**
     * @member {string} [description] Description of the new application.
     * Optional.
     */
    description?: string;
    /**
     * @member {string} [initialVersionId] The initial version ID. Optional.
     * Default value is: "0.1"
     */
    initialVersionId?: string;
    /**
     * @member {string} [usageScenario] Defines the scenario for the new
     * application. Optional. E.g.: IoT.
     */
    usageScenario?: string;
    /**
     * @member {string} name The name for the new application.
     */
    name: string;
}
/**
 * @interface
 * An interface representing PrebuiltDomainCreateBaseObject.
 * A model object containing the name of the custom prebuilt entity and the
 * name of the domain to which this model belongs.
 *
 */
export interface PrebuiltDomainCreateBaseObject {
    /**
     * @member {string} [domainName] The domain name.
     */
    domainName?: string;
}
/**
 * @interface
 * An interface representing PrebuiltDomainCreateObject.
 * A prebuilt domain create object containing the name and culture of the
 * domain.
 *
 */
export interface PrebuiltDomainCreateObject {
    /**
     * @member {string} [domainName] The domain name.
     */
    domainName?: string;
    /**
     * @member {string} [culture] The culture of the new domain.
     */
    culture?: string;
}
/**
 * @interface
 * An interface representing PrebuiltDomainModelCreateObject.
 * A model object containing the name of the custom prebuilt intent or entity
 * and the name of the domain to which this model belongs.
 *
 */
export interface PrebuiltDomainModelCreateObject {
    /**
     * @member {string} [domainName] The domain name.
     */
    domainName?: string;
    /**
     * @member {string} [modelName] The intent name or entity name.
     */
    modelName?: string;
}
/**
 * @interface
 * An interface representing HierarchicalEntityModel.
 * A hierarchical entity extractor.
 *
 */
export interface HierarchicalEntityModel {
    /**
     * @member {string[]} [children] Child entities.
     */
    children?: string[];
    /**
     * @member {string} [name] Entity name.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing CompositeEntityModel.
 * A composite entity extractor.
 *
 */
export interface CompositeEntityModel {
    /**
     * @member {string[]} [children] Child entities.
     */
    children?: string[];
    /**
     * @member {string} [name] Entity name.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing JSONEntity.
 * Exported Model - Extracted Entity from utterance.
 *
 */
export interface JSONEntity {
    /**
     * @member {number} startPos The index within the utterance where the
     * extracted entity starts.
     */
    startPos: number;
    /**
     * @member {number} endPos The index within the utterance where the extracted
     * entity ends.
     */
    endPos: number;
    /**
     * @member {string} entity The entity name.
     */
    entity: string;
    /**
     * @member {string} [role] The role the entity plays in the utterance.
     */
    role?: string;
}
/**
 * @interface
 * An interface representing ApplicationSettingUpdateObject.
 * Object model for updating an application's settings.
 *
 */
export interface ApplicationSettingUpdateObject {
    /**
     * @member {boolean} [isPublic] Setting your application as public allows
     * other people to use your application's endpoint using their own keys.
     */
    isPublic?: boolean;
}
/**
 * @interface
 * An interface representing PublishSettingUpdateObject.
 * Object model for updating an application's publish settings.
 *
 */
export interface PublishSettingUpdateObject {
    /**
     * @member {boolean} [sentimentAnalysis] Setting sentiment analysis as true
     * returns the Sentiment of the input utterance along with the response
     */
    sentimentAnalysis?: boolean;
    /**
     * @member {boolean} [speech] Setting speech as public enables speech priming
     * in your app
     */
    speech?: boolean;
    /**
     * @member {boolean} [spellChecker] Setting spell checker as public enables
     * spell checking the input utterance.
     */
    spellChecker?: boolean;
}
/**
 * @interface
 * An interface representing ExampleLabelObject.
 * A labeled example utterance.
 *
 */
export interface ExampleLabelObject {
    /**
     * @member {string} [text] The example utterance.
     */
    text?: string;
    /**
     * @member {EntityLabelObject[]} [entityLabels] The identified entities
     * within the example utterance.
     */
    entityLabels?: EntityLabelObject[];
    /**
     * @member {string} [intentName] The identified intent representing the
     * example utterance.
     */
    intentName?: string;
}
/**
 * @interface
 * An interface representing PhraselistCreateObject.
 * Object model for creating a phraselist model.
 *
 */
export interface PhraselistCreateObject {
    /**
     * @member {string} [phrases] List of comma-separated phrases that represent
     * the Phraselist.
     */
    phrases?: string;
    /**
     * @member {string} [name] The Phraselist name.
     */
    name?: string;
    /**
     * @member {boolean} [isExchangeable] An interchangeable phrase list feature
     * serves as a list of synonyms for training. A non-exchangeable phrase list
     * serves as separate features for training. So, if your non-interchangeable
     * phrase list contains 5 phrases, they will be mapped to 5 separate
     * features. You can think of the non-interchangeable phrase list as an
     * additional bag of words to add to LUIS existing vocabulary features. It is
     * used as a lexicon lookup feature where its value is 1 if the lexicon
     * contains a given word or 0 if it doesn’t.  Default value is true. Default
     * value: true .
     */
    isExchangeable?: boolean;
}
/**
 * @interface
 * An interface representing SubClosedList.
 * Sublist of items for a list entity.
 *
 */
export interface SubClosedList {
    /**
     * @member {string} [canonicalForm] The standard form that the list
     * represents.
     */
    canonicalForm?: string;
    /**
     * @member {string[]} [list] List of synonym words.
     */
    list?: string[];
}
/**
 * @interface
 * An interface representing SubClosedListResponse.
 * Sublist of items for a list entity.
 *
 * @extends SubClosedList
 */
export interface SubClosedListResponse extends SubClosedList {
    /**
     * @member {number} [id] The sublist ID
     */
    id?: number;
}
/**
 * @interface
 * An interface representing ApplicationUpdateObject.
 * Object model for updating the name or description of an application.
 *
 */
export interface ApplicationUpdateObject {
    /**
     * @member {string} [name] The application's new name.
     */
    name?: string;
    /**
     * @member {string} [description] The application's new description.
     */
    description?: string;
}
/**
 * @interface
 * An interface representing JSONRegexFeature.
 * Exported Model - A Pattern feature.
 *
 */
export interface JSONRegexFeature {
    /**
     * @member {string} [pattern] The Regular Expression to match.
     */
    pattern?: string;
    /**
     * @member {boolean} [activated] Indicates if the Pattern feature is enabled.
     */
    activated?: boolean;
    /**
     * @member {string} [name] Name of the feature.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing PatternUpdateObject.
 * Object model for updating an existing Pattern feature.
 *
 */
export interface PatternUpdateObject {
    /**
     * @member {string} [pattern] The Regular Expression to match.
     */
    pattern?: string;
    /**
     * @member {string} [name] Name of the feature.
     */
    name?: string;
    /**
     * @member {boolean} [isActive] Indicates if the Pattern feature is enabled.
     * Default value: true .
     */
    isActive?: boolean;
}
/**
 * @interface
 * An interface representing ClosedList.
 * Exported Model - A list entity.
 *
 */
export interface ClosedList {
    /**
     * @member {string} [name] Name of the list entity.
     */
    name?: string;
    /**
     * @member {SubClosedList[]} [subLists] Sublists for the list entity.
     */
    subLists?: SubClosedList[];
    /**
     * @member {string[]} [roles]
     */
    roles?: string[];
}
/**
 * @interface
 * An interface representing WordListObject.
 * Sublist of items for a list entity.
 *
 */
export interface WordListObject {
    /**
     * @member {string} [canonicalForm] The standard form that the list
     * represents.
     */
    canonicalForm?: string;
    /**
     * @member {string[]} [list] List of synonym words.
     */
    list?: string[];
}
/**
 * @interface
 * An interface representing ClosedListModelPatchObject.
 * Object model for adding a batch of sublists to an existing list entity.
 *
 */
export interface ClosedListModelPatchObject {
    /**
     * @member {WordListObject[]} [subLists] Sublists to add.
     */
    subLists?: WordListObject[];
}
/**
 * @interface
 * An interface representing JSONModelFeature.
 * Exported Model - Phraselist Model Feature.
 *
 */
export interface JSONModelFeature {
    /**
     * @member {boolean} [activated] Indicates if the feature is enabled.
     */
    activated?: boolean;
    /**
     * @member {string} [name] The Phraselist name.
     */
    name?: string;
    /**
     * @member {string} [words] List of comma-separated phrases that represent
     * the Phraselist.
     */
    words?: string;
    /**
     * @member {boolean} [mode] An interchangeable phrase list feature serves as
     * a list of synonyms for training. A non-exchangeable phrase list serves as
     * separate features for training. So, if your non-interchangeable phrase
     * list contains 5 phrases, they will be mapped to 5 separate features. You
     * can think of the non-interchangeable phrase list as an additional bag of
     * words to add to LUIS existing vocabulary features. It is used as a lexicon
     * lookup feature where its value is 1 if the lexicon contains a given word
     * or 0 if it doesn’t.  Default value is true.
     */
    mode?: boolean;
}
/**
 * @interface
 * An interface representing ModelCreateObject.
 * Object model for creating a new entity extractor.
 *
 */
export interface ModelCreateObject {
    /**
     * @member {string} [name] Name of the new entity extractor.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing PatternCreateObject.
 * Object model for creating a Pattern feature.
 *
 */
export interface PatternCreateObject {
    /**
     * @member {string} [pattern] The Regular Expression to match.
     */
    pattern?: string;
    /**
     * @member {string} [name] Name of the feature.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing WordListBaseUpdateObject.
 * Object model for updating one of the list entity's sublists.
 *
 */
export interface WordListBaseUpdateObject {
    /**
     * @member {string} [canonicalForm] The standard form that the list
     * represents.
     */
    canonicalForm?: string;
    /**
     * @member {string[]} [list] List of synonym words.
     */
    list?: string[];
}
/**
 * @interface
 * An interface representing JSONUtterance.
 * Exported Model - Utterance that was used to train the model.
 *
 */
export interface JSONUtterance {
    /**
     * @member {string} [text] The utterance.
     */
    text?: string;
    /**
     * @member {string} [intent] The matched intent.
     */
    intent?: string;
    /**
     * @member {JSONEntity[]} [entities] The matched entities.
     */
    entities?: JSONEntity[];
}
/**
 * @interface
 * An interface representing ModelUpdateObject.
 * Object model for updating an intent classifier.
 *
 */
export interface ModelUpdateObject {
    /**
     * @member {string} [name] The entity's new name.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing ClosedListModelUpdateObject.
 * Object model for updating a list entity.
 *
 */
export interface ClosedListModelUpdateObject {
    /**
     * @member {WordListObject[]} [subLists] The new sublists for the feature.
     */
    subLists?: WordListObject[];
    /**
     * @member {string} [name] The new name of the list entity.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing ClosedListModelCreateObject.
 * Object model for creating a list entity.
 *
 */
export interface ClosedListModelCreateObject {
    /**
     * @member {WordListObject[]} [subLists] Sublists for the feature.
     */
    subLists?: WordListObject[];
    /**
     * @member {string} [name] Name of the list entity.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing VersionInfo.
 * Object model of an application version.
 *
 */
export interface VersionInfo {
    /**
     * @member {string} version The version ID. E.g.: "0.1"
     */
    version: string;
    /**
     * @member {Date} [createdDateTime] The version's creation timestamp.
     */
    createdDateTime?: Date;
    /**
     * @member {Date} [lastModifiedDateTime] Timestamp of the last update.
     */
    lastModifiedDateTime?: Date;
    /**
     * @member {Date} [lastTrainedDateTime] Timestamp of the last time the model
     * was trained.
     */
    lastTrainedDateTime?: Date;
    /**
     * @member {Date} [lastPublishedDateTime] Timestamp when was last published.
     */
    lastPublishedDateTime?: Date;
    /**
     * @member {string} [endpointUrl] The Runtime endpoint URL for this model
     * version.
     */
    endpointUrl?: string;
    /**
     * @member {{ [propertyName: string]: string }} [assignedEndpointKey] The
     * endpoint key.
     */
    assignedEndpointKey?: {
        [propertyName: string]: string;
    };
    /**
     * @member {any} [externalApiKeys] External keys.
     */
    externalApiKeys?: any;
    /**
     * @member {number} [intentsCount] Number of intents in this model.
     */
    intentsCount?: number;
    /**
     * @member {number} [entitiesCount] Number of entities in this model.
     */
    entitiesCount?: number;
    /**
     * @member {number} [endpointHitsCount] Number of calls made to this
     * endpoint.
     */
    endpointHitsCount?: number;
    /**
     * @member {TrainingStatus} trainingStatus The current training status.
     * Possible values include: 'NeedsTraining', 'InProgress', 'Trained'
     */
    trainingStatus: TrainingStatus;
}
/**
 * @interface
 * An interface representing TaskUpdateObject.
 * Object model for cloning an application's version.
 *
 */
export interface TaskUpdateObject {
    /**
     * @member {string} [version] The new version for the cloned model.
     */
    version?: string;
}
/**
 * @interface
 * An interface representing PhraselistUpdateObject.
 * Object model for updating a Phraselist.
 *
 */
export interface PhraselistUpdateObject {
    /**
     * @member {string} [phrases] List of comma-separated phrases that represent
     * the Phraselist.
     */
    phrases?: string;
    /**
     * @member {string} [name] The Phraselist name.
     */
    name?: string;
    /**
     * @member {boolean} [isActive] Indicates if the Phraselist is enabled.
     * Default value: true .
     */
    isActive?: boolean;
    /**
     * @member {boolean} [isExchangeable] An exchangeable phrase list feature are
     * serves as single feature to the LUIS underlying training algorithm. It is
     * used as a lexicon lookup feature where its value is 1 if the lexicon
     * contains a given word or 0 if it doesn’t. Think of an exchangeable as a
     * synonyms list. A non-exchangeable phrase list feature has all the phrases
     * in the list serve as separate features to the underlying training
     * algorithm. So, if you your phrase list feature contains 5 phrases, they
     * will be mapped to 5 separate features. You can think of the
     * non-exchangeable phrase list feature as an additional bag of words that
     * you are willing to add to LUIS existing vocabulary features. Think of a
     * non-exchangeable as set of different words. Default value is true. Default
     * value: true .
     */
    isExchangeable?: boolean;
}
/**
 * @interface
 * An interface representing PrebuiltDomainObject.
 */
export interface PrebuiltDomainObject {
    /**
     * @member {string} [domainName]
     */
    domainName?: string;
    /**
     * @member {string} [modelName]
     */
    modelName?: string;
}
/**
 * @interface
 * An interface representing HierarchicalModel.
 */
export interface HierarchicalModel {
    /**
     * @member {string} [name]
     */
    name?: string;
    /**
     * @member {string[]} [children]
     */
    children?: string[];
    /**
     * @member {PrebuiltDomainObject} [inherits]
     */
    inherits?: PrebuiltDomainObject;
    /**
     * @member {string[]} [roles]
     */
    roles?: string[];
}
/**
 * @interface
 * An interface representing ApplicationPublishObject.
 * Object model for publishing a specific application version.
 *
 */
export interface ApplicationPublishObject {
    /**
     * @member {string} [versionId] The version ID to publish.
     */
    versionId?: string;
    /**
     * @member {boolean} [isStaging] Indicates if the staging slot should be
     * used, instead of the Production one. Default value: false .
     */
    isStaging?: boolean;
}
/**
 * @interface
 * An interface representing PatternAny.
 * Pattern.Any Entity Extractor.
 *
 */
export interface PatternAny {
    /**
     * @member {string} [name]
     */
    name?: string;
    /**
     * @member {string[]} [explicitList]
     */
    explicitList?: string[];
    /**
     * @member {string[]} [roles]
     */
    roles?: string[];
}
/**
 * @interface
 * An interface representing RegexEntity.
 * Regular Expression Entity Extractor.
 *
 */
export interface RegexEntity {
    /**
     * @member {string} [name]
     */
    name?: string;
    /**
     * @member {string} [regexPattern]
     */
    regexPattern?: string;
    /**
     * @member {string[]} [roles]
     */
    roles?: string[];
}
/**
 * @interface
 * An interface representing PrebuiltEntity.
 * Prebuilt Entity Extractor.
 *
 */
export interface PrebuiltEntity {
    /**
     * @member {string} [name]
     */
    name?: string;
    /**
     * @member {string[]} [roles]
     */
    roles?: string[];
}
/**
 * @interface
 * An interface representing PatternRule.
 * Pattern
 *
 */
export interface PatternRule {
    /**
     * @member {string} [pattern] The pattern text.
     */
    pattern?: string;
    /**
     * @member {string} [intent] The intent's name where the pattern belongs to.
     */
    intent?: string;
}
/**
 * @interface
 * An interface representing LuisApp.
 * Exported Model - An exported LUIS Application.
 *
 */
export interface LuisApp {
    /**
     * @member {string} [name] The name of the application.
     */
    name?: string;
    /**
     * @member {string} [versionId] The version ID of the application that was
     * exported.
     */
    versionId?: string;
    /**
     * @member {string} [desc] The description of the application.
     */
    desc?: string;
    /**
     * @member {string} [culture] The culture of the application. E.g.: en-us.
     */
    culture?: string;
    /**
     * @member {HierarchicalModel[]} [intents] List of intents.
     */
    intents?: HierarchicalModel[];
    /**
     * @member {HierarchicalModel[]} [entities] List of entities.
     */
    entities?: HierarchicalModel[];
    /**
     * @member {ClosedList[]} [closedLists] List of list entities.
     */
    closedLists?: ClosedList[];
    /**
     * @member {HierarchicalModel[]} [composites] List of composite entities.
     */
    composites?: HierarchicalModel[];
    /**
     * @member {PatternAny[]} [patternAnyEntities] List of Pattern.Any entities.
     */
    patternAnyEntities?: PatternAny[];
    /**
     * @member {RegexEntity[]} [regexEntities] List of regular expression
     * entities.
     */
    regexEntities?: RegexEntity[];
    /**
     * @member {PrebuiltEntity[]} [prebuiltEntities] List of prebuilt entities.
     */
    prebuiltEntities?: PrebuiltEntity[];
    /**
     * @member {JSONRegexFeature[]} [regexFeatures] List of pattern features.
     */
    regexFeatures?: JSONRegexFeature[];
    /**
     * @member {JSONModelFeature[]} [modelFeatures] List of model features.
     */
    modelFeatures?: JSONModelFeature[];
    /**
     * @member {PatternRule[]} [patterns] List of patterns.
     */
    patterns?: PatternRule[];
    /**
     * @member {JSONUtterance[]} [utterances] List of example utterances.
     */
    utterances?: JSONUtterance[];
    /**
     * @property Describes unknown properties. The value of an unknown property
     * can be of "any" type.
     */
    [property: string]: any;
}
/**
 * @interface
 * An interface representing EntityLabel.
 * Defines the entity type and position of the extracted entity within the
 * example.
 *
 */
export interface EntityLabel {
    /**
     * @member {string} entityName The entity type.
     */
    entityName: string;
    /**
     * @member {number} startTokenIndex The index within the utterance where the
     * extracted entity starts.
     */
    startTokenIndex: number;
    /**
     * @member {number} endTokenIndex The index within the utterance where the
     * extracted entity ends.
     */
    endTokenIndex: number;
    /**
     * @member {string} [role] The role of the predicted entity.
     */
    role?: string;
    /**
     * @member {string} [roleId] The role id for the predicted entity.
     */
    roleId?: string;
}
/**
 * @interface
 * An interface representing IntentPrediction.
 * A suggested intent.
 *
 */
export interface IntentPrediction {
    /**
     * @member {string} [name] The intent's name
     */
    name?: string;
    /**
     * @member {number} [score] The intent's score, based on the prediction
     * model.
     */
    score?: number;
}
/**
 * @interface
 * An interface representing EntityPrediction.
 * A suggested entity.
 *
 */
export interface EntityPrediction {
    /**
     * @member {string} entityName The entity's name
     */
    entityName: string;
    /**
     * @member {number} startTokenIndex The index within the utterance where the
     * extracted entity starts.
     */
    startTokenIndex: number;
    /**
     * @member {number} endTokenIndex The index within the utterance where the
     * extracted entity ends.
     */
    endTokenIndex: number;
    /**
     * @member {string} phrase The actual token(s) that comprise the entity.
     */
    phrase: string;
}
/**
 * @interface
 * An interface representing LabeledUtterance.
 * A prediction and label pair of an example.
 *
 */
export interface LabeledUtterance {
    /**
     * @member {number} [id] ID of Labeled Utterance.
     */
    id?: number;
    /**
     * @member {string} [text] The utterance. For example, "What's the weather
     * like in seattle?"
     */
    text?: string;
    /**
     * @member {string[]} [tokenizedText] The utterance tokenized.
     */
    tokenizedText?: string[];
    /**
     * @member {string} [intentLabel] The intent matching the example.
     */
    intentLabel?: string;
    /**
     * @member {EntityLabel[]} [entityLabels] The entities matching the example.
     */
    entityLabels?: EntityLabel[];
    /**
     * @member {IntentPrediction[]} [intentPredictions] List of suggested
     * intents.
     */
    intentPredictions?: IntentPrediction[];
    /**
     * @member {EntityPrediction[]} [entityPredictions] List of suggested
     * entities.
     */
    entityPredictions?: EntityPrediction[];
}
/**
 * @interface
 * An interface representing IntentsSuggestionExample.
 * Predicted/suggested intent.
 *
 */
export interface IntentsSuggestionExample {
    /**
     * @member {string} [text] The utterance. For example, "What's the weather
     * like in seattle?"
     */
    text?: string;
    /**
     * @member {string[]} [tokenizedText] The tokenized utterance.
     */
    tokenizedText?: string[];
    /**
     * @member {IntentPrediction[]} [intentPredictions] Predicted/suggested
     * intents.
     */
    intentPredictions?: IntentPrediction[];
    /**
     * @member {EntityPrediction[]} [entityPredictions] Predicted/suggested
     * entities.
     */
    entityPredictions?: EntityPrediction[];
}
/**
 * @interface
 * An interface representing EntitiesSuggestionExample.
 * Predicted/suggested entity.
 *
 */
export interface EntitiesSuggestionExample {
    /**
     * @member {string} [text] The utterance. For example, "What's the weather
     * like in seattle?"
     */
    text?: string;
    /**
     * @member {string[]} [tokenizedText] The utterance tokenized.
     */
    tokenizedText?: string[];
    /**
     * @member {IntentPrediction[]} [intentPredictions] Predicted/suggested
     * intents.
     */
    intentPredictions?: IntentPrediction[];
    /**
     * @member {EntityPrediction[]} [entityPredictions] Predicted/suggested
     * entities.
     */
    entityPredictions?: EntityPrediction[];
}
/**
 * @interface
 * An interface representing PersonalAssistantsResponse.
 * Response containing user's endpoint keys and the endpoint URLs of the
 * prebuilt Cortana applications.
 *
 */
export interface PersonalAssistantsResponse {
    /**
     * @member {string[]} [endpointKeys]
     */
    endpointKeys?: string[];
    /**
     * @member {{ [propertyName: string]: string }} [endpointUrls]
     */
    endpointUrls?: {
        [propertyName: string]: string;
    };
}
/**
 * @interface
 * An interface representing ModelInfo.
 * Base type used in entity types.
 *
 */
export interface ModelInfo {
    /**
     * @member {string} id The ID of the Entity Model.
     */
    id: string;
    /**
     * @member {string} [name] Name of the Entity Model.
     */
    name?: string;
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType} readableType Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType: ReadableType;
}
/**
 * @interface
 * An interface representing EntityRole.
 * Entity extractor role
 *
 */
export interface EntityRole {
    /**
     * @member {string} [id] The entity role ID.
     */
    id?: string;
    /**
     * @member {string} [name] The entity role name.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing ChildEntity.
 * The base child entity type.
 *
 */
export interface ChildEntity {
    /**
     * @member {string} id The ID (GUID) belonging to a child entity.
     */
    id: string;
    /**
     * @member {string} [name] The name of a child entity.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing ExplicitListItem.
 * Explicit (exception) list item
 *
 */
export interface ExplicitListItem {
    /**
     * @member {number} [id] The explicit list item ID.
     */
    id?: number;
    /**
     * @member {string} [explicitListItem] The explicit list item value.
     */
    explicitListItem?: string;
}
/**
 * @interface
 * An interface representing ModelInfoResponse.
 * An application model info.
 *
 */
export interface ModelInfoResponse {
    /**
     * @member {string} id The ID of the Entity Model.
     */
    id: string;
    /**
     * @member {string} [name] Name of the Entity Model.
     */
    name?: string;
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType1} readableType Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType: ReadableType1;
    /**
     * @member {EntityRole[]} [roles]
     */
    roles?: EntityRole[];
    /**
     * @member {ChildEntity[]} [children] List of child entities.
     */
    children?: ChildEntity[];
    /**
     * @member {SubClosedListResponse[]} [subLists] List of sublists.
     */
    subLists?: SubClosedListResponse[];
    /**
     * @member {string} [customPrebuiltDomainName] The domain name.
     */
    customPrebuiltDomainName?: string;
    /**
     * @member {string} [customPrebuiltModelName] The intent name or entity name.
     */
    customPrebuiltModelName?: string;
    /**
     * @member {string} [regexPattern] The Regular Expression entity pattern.
     */
    regexPattern?: string;
    /**
     * @member {ExplicitListItem[]} [explicitList]
     */
    explicitList?: ExplicitListItem[];
}
/**
 * @interface
 * An interface representing EntityModelInfo.
 * An Entity Extractor model info.
 *
 * @extends ModelInfo
 */
export interface EntityModelInfo extends ModelInfo {
    /**
     * @member {EntityRole[]} [roles]
     */
    roles?: EntityRole[];
}
/**
 * @interface
 * An interface representing HierarchicalEntityExtractor.
 * Hierarchical Entity Extractor.
 *
 */
export interface HierarchicalEntityExtractor {
    /**
     * @member {string} id The ID of the Entity Model.
     */
    id: string;
    /**
     * @member {string} [name] Name of the Entity Model.
     */
    name?: string;
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType2} readableType Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType: ReadableType2;
    /**
     * @member {EntityRole[]} [roles]
     */
    roles?: EntityRole[];
    /**
     * @member {ChildEntity[]} [children] List of child entities.
     */
    children?: ChildEntity[];
}
/**
 * @interface
 * An interface representing CompositeEntityExtractor.
 * A Composite Entity Extractor.
 *
 */
export interface CompositeEntityExtractor {
    /**
     * @member {string} id The ID of the Entity Model.
     */
    id: string;
    /**
     * @member {string} [name] Name of the Entity Model.
     */
    name?: string;
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType3} readableType Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType: ReadableType3;
    /**
     * @member {EntityRole[]} [roles]
     */
    roles?: EntityRole[];
    /**
     * @member {ChildEntity[]} [children] List of child entities.
     */
    children?: ChildEntity[];
}
/**
 * @interface
 * An interface representing ClosedListEntityExtractor.
 * List Entity Extractor.
 *
 */
export interface ClosedListEntityExtractor {
    /**
     * @member {string} id The ID of the Entity Model.
     */
    id: string;
    /**
     * @member {string} [name] Name of the Entity Model.
     */
    name?: string;
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType4} readableType Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType: ReadableType4;
    /**
     * @member {EntityRole[]} [roles]
     */
    roles?: EntityRole[];
    /**
     * @member {SubClosedListResponse[]} [subLists] List of sublists.
     */
    subLists?: SubClosedListResponse[];
}
/**
 * @interface
 * An interface representing PrebuiltEntityExtractor.
 * Prebuilt Entity Extractor.
 *
 */
export interface PrebuiltEntityExtractor {
    /**
     * @member {string} id The ID of the Entity Model.
     */
    id: string;
    /**
     * @member {string} [name] Name of the Entity Model.
     */
    name?: string;
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType5} readableType Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType: ReadableType5;
    /**
     * @member {EntityRole[]} [roles]
     */
    roles?: EntityRole[];
}
/**
 * @interface
 * An interface representing HierarchicalChildEntity.
 * A Hierarchical Child Entity.
 *
 * @extends ChildEntity
 */
export interface HierarchicalChildEntity extends ChildEntity {
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType6} [readableType] Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType?: ReadableType6;
}
/**
 * @interface
 * An interface representing CustomPrebuiltModel.
 * A Custom Prebuilt model.
 *
 */
export interface CustomPrebuiltModel {
    /**
     * @member {string} id The ID of the Entity Model.
     */
    id: string;
    /**
     * @member {string} [name] Name of the Entity Model.
     */
    name?: string;
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType7} readableType Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType: ReadableType7;
    /**
     * @member {string} [customPrebuiltDomainName] The domain name.
     */
    customPrebuiltDomainName?: string;
    /**
     * @member {string} [customPrebuiltModelName] The intent name or entity name.
     */
    customPrebuiltModelName?: string;
    /**
     * @member {EntityRole[]} [roles]
     */
    roles?: EntityRole[];
}
/**
 * @interface
 * An interface representing IntentClassifier.
 * Intent Classifier.
 *
 * @extends ModelInfo
 */
export interface IntentClassifier extends ModelInfo {
    /**
     * @member {string} [customPrebuiltDomainName] The domain name.
     */
    customPrebuiltDomainName?: string;
    /**
     * @member {string} [customPrebuiltModelName] The intent name or entity name.
     */
    customPrebuiltModelName?: string;
}
/**
 * @interface
 * An interface representing EntityExtractor.
 * Entity Extractor.
 *
 */
export interface EntityExtractor {
    /**
     * @member {string} id The ID of the Entity Model.
     */
    id: string;
    /**
     * @member {string} [name] Name of the Entity Model.
     */
    name?: string;
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType8} readableType Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType: ReadableType8;
    /**
     * @member {EntityRole[]} [roles]
     */
    roles?: EntityRole[];
    /**
     * @member {string} [customPrebuiltDomainName] The domain name.
     */
    customPrebuiltDomainName?: string;
    /**
     * @member {string} [customPrebuiltModelName] The intent name or entity name.
     */
    customPrebuiltModelName?: string;
}
/**
 * @interface
 * An interface representing FeatureInfoObject.
 * The base class Features-related response objects inherit from.
 *
 */
export interface FeatureInfoObject {
    /**
     * @member {number} [id] A six-digit ID used for Features.
     */
    id?: number;
    /**
     * @member {string} [name] The name of the Feature.
     */
    name?: string;
    /**
     * @member {boolean} [isActive] Indicates if the feature is enabled.
     */
    isActive?: boolean;
}
/**
 * @interface
 * An interface representing PhraseListFeatureInfo.
 * Phraselist Feature.
 *
 * @extends FeatureInfoObject
 */
export interface PhraseListFeatureInfo extends FeatureInfoObject {
    /**
     * @member {string} [phrases] A list of comma-separated values.
     */
    phrases?: string;
    /**
     * @member {boolean} [isExchangeable] An exchangeable phrase list feature are
     * serves as single feature to the LUIS underlying training algorithm. It is
     * used as a lexicon lookup feature where its value is 1 if the lexicon
     * contains a given word or 0 if it doesn’t. Think of an exchangeable as a
     * synonyms list. A non-exchangeable phrase list feature has all the phrases
     * in the list serve as separate features to the underlying training
     * algorithm. So, if you your phrase list feature contains 5 phrases, they
     * will be mapped to 5 separate features. You can think of the
     * non-exchangeable phrase list feature as an additional bag of words that
     * you are willing to add to LUIS existing vocabulary features. Think of a
     * non-exchangeable as set of different words. Default value is true.
     */
    isExchangeable?: boolean;
}
/**
 * @interface
 * An interface representing PatternFeatureInfo.
 * Pattern feature.
 *
 * @extends FeatureInfoObject
 */
export interface PatternFeatureInfo extends FeatureInfoObject {
    /**
     * @member {string} [pattern] The Regular Expression to match.
     */
    pattern?: string;
}
/**
 * @interface
 * An interface representing FeaturesResponseObject.
 * Model Features, including Patterns and Phraselists.
 *
 */
export interface FeaturesResponseObject {
    /**
     * @member {PhraseListFeatureInfo[]} [phraselistFeatures]
     */
    phraselistFeatures?: PhraseListFeatureInfo[];
    /**
     * @member {PatternFeatureInfo[]} [patternFeatures]
     */
    patternFeatures?: PatternFeatureInfo[];
}
/**
 * @interface
 * An interface representing LabelExampleResponse.
 * Response when adding a labeled example utterance.
 *
 */
export interface LabelExampleResponse {
    /**
     * @member {string} [utteranceText] The example utterance.
     */
    utteranceText?: string;
    /**
     * @member {number} [exampleId] The newly created sample ID.
     */
    exampleId?: number;
}
/**
 * @interface
 * An interface representing OperationStatus.
 * Response of an Operation status.
 *
 */
export interface OperationStatus {
    /**
     * @member {OperationStatusType} [code] Status Code. Possible values include:
     * 'Failed', 'FAILED', 'Success'
     */
    code?: OperationStatusType;
    /**
     * @member {string} [message] Status details.
     */
    message?: string;
}
/**
 * @interface
 * An interface representing BatchLabelExample.
 * Response when adding a batch of labeled example utterances.
 *
 */
export interface BatchLabelExample {
    /**
     * @member {LabelExampleResponse} [value]
     */
    value?: LabelExampleResponse;
    /**
     * @member {boolean} [hasError]
     */
    hasError?: boolean;
    /**
     * @member {OperationStatus} [error]
     */
    error?: OperationStatus;
}
/**
 * @interface
 * An interface representing ApplicationInfoResponse.
 * Response containing the Application Info.
 *
 */
export interface ApplicationInfoResponse {
    /**
     * @member {string} [id] The ID (GUID) of the application.
     */
    id?: string;
    /**
     * @member {string} [name] The name of the application.
     */
    name?: string;
    /**
     * @member {string} [description] The description of the application.
     */
    description?: string;
    /**
     * @member {string} [culture] The culture of the application. For example,
     * "en-us".
     */
    culture?: string;
    /**
     * @member {string} [usageScenario] Defines the scenario for the new
     * application. Optional. For example, IoT.
     */
    usageScenario?: string;
    /**
     * @member {string} [domain] The domain for the new application. Optional.
     * For example, Comics.
     */
    domain?: string;
    /**
     * @member {number} [versionsCount] Amount of model versions within the
     * application.
     */
    versionsCount?: number;
    /**
     * @member {string} [createdDateTime] The version's creation timestamp.
     */
    createdDateTime?: string;
    /**
     * @member {any} [endpoints] The Runtime endpoint URL for this model version.
     */
    endpoints?: any;
    /**
     * @member {number} [endpointHitsCount] Number of calls made to this
     * endpoint.
     */
    endpointHitsCount?: number;
    /**
     * @member {string} [activeVersion] The version ID currently marked as
     * active.
     */
    activeVersion?: string;
}
/**
 * @interface
 * An interface representing EndpointInfo.
 * The base class "ProductionOrStagingEndpointInfo" inherits from.
 *
 */
export interface EndpointInfo {
    /**
     * @member {string} [versionId] The version ID to publish.
     */
    versionId?: string;
    /**
     * @member {boolean} [isStaging] Indicates if the staging slot should be
     * used, instead of the Production one.
     */
    isStaging?: boolean;
    /**
     * @member {string} [endpointUrl] The Runtime endpoint URL for this model
     * version.
     */
    endpointUrl?: string;
    /**
     * @member {string} [region] The target region that the application is
     * published to.
     */
    region?: string;
    /**
     * @member {string} [assignedEndpointKey] The endpoint key.
     */
    assignedEndpointKey?: string;
    /**
     * @member {string} [endpointRegion] The endpoint's region.
     */
    endpointRegion?: string;
    /**
     * @member {string} [failedRegions] Regions where publishing failed.
     */
    failedRegions?: string;
    /**
     * @member {string} [publishedDateTime] Timestamp when was last published.
     */
    publishedDateTime?: string;
}
/**
 * @interface
 * An interface representing ProductionOrStagingEndpointInfo.
 * @extends EndpointInfo
 */
export interface ProductionOrStagingEndpointInfo extends EndpointInfo {
}
/**
 * @interface
 * An interface representing AvailableCulture.
 * Available culture for using in a new application.
 *
 */
export interface AvailableCulture {
    /**
     * @member {string} [name] The language name.
     */
    name?: string;
    /**
     * @member {string} [code] The ISO value for the language.
     */
    code?: string;
}
/**
 * @interface
 * An interface representing ApplicationSettings.
 * The application settings.
 *
 */
export interface ApplicationSettings {
    /**
     * @member {string} id The application ID.
     */
    id: string;
    /**
     * @member {boolean} isPublic Setting your application as public allows other
     * people to use your application's endpoint using their own keys for billing
     * purposes.
     */
    isPublic: boolean;
}
/**
 * @interface
 * An interface representing PublishSettings.
 * The application publish settings.
 *
 */
export interface PublishSettings {
    /**
     * @member {string} id The application ID.
     */
    id: string;
    /**
     * @member {boolean} isSentimentAnalysisEnabled Setting sentiment analysis as
     * true returns the sentiment of the input utterance along with the response
     */
    isSentimentAnalysisEnabled: boolean;
    /**
     * @member {boolean} isSpeechEnabled Enables speech priming in your app
     */
    isSpeechEnabled: boolean;
    /**
     * @member {boolean} isSpellCheckerEnabled Enables spell checking of the
     * utterance.
     */
    isSpellCheckerEnabled: boolean;
}
/**
 * @interface
 * An interface representing AvailablePrebuiltEntityModel.
 * Available Prebuilt entity model for using in an application.
 *
 */
export interface AvailablePrebuiltEntityModel {
    /**
     * @member {string} [name] The entity name.
     */
    name?: string;
    /**
     * @member {string} [description] The entity description and usage
     * information.
     */
    description?: string;
    /**
     * @member {string} [examples] Usage examples.
     */
    examples?: string;
}
/**
 * @interface
 * An interface representing EnqueueTrainingResponse.
 * Response model when requesting to train the model.
 *
 */
export interface EnqueueTrainingResponse {
    /**
     * @member {number} [statusId] The train request status ID.
     */
    statusId?: number;
    /**
     * @member {Status} [status] Possible values include: 'Queued', 'InProgress',
     * 'UpToDate', 'Fail', 'Success'
     */
    status?: Status;
}
/**
 * @interface
 * An interface representing ModelTrainingDetails.
 * Model Training Details.
 *
 */
export interface ModelTrainingDetails {
    /**
     * @member {number} [statusId] The train request status ID.
     */
    statusId?: number;
    /**
     * @member {Status1} [status] Possible values include: 'Queued',
     * 'InProgress', 'UpToDate', 'Fail', 'Success'
     */
    status?: Status1;
    /**
     * @member {number} [exampleCount] The count of examples used to train the
     * model.
     */
    exampleCount?: number;
    /**
     * @member {Date} [trainingDateTime] When the model was trained.
     */
    trainingDateTime?: Date;
    /**
     * @member {string} [failureReason] Reason for the training failure.
     */
    failureReason?: string;
}
/**
 * @interface
 * An interface representing ModelTrainingInfo.
 * Model Training Info.
 *
 */
export interface ModelTrainingInfo {
    /**
     * @member {string} [modelId] The ID (GUID) of the model.
     */
    modelId?: string;
    /**
     * @member {ModelTrainingDetails} [details]
     */
    details?: ModelTrainingDetails;
}
/**
 * @interface
 * An interface representing UserAccessList.
 * List of user permissions.
 *
 */
export interface UserAccessList {
    /**
     * @member {string} [owner] The email address of owner of the application.
     */
    owner?: string;
    /**
     * @member {string[]} [emails]
     */
    emails?: string[];
}
/**
 * @interface
 * An interface representing UserCollaborator.
 */
export interface UserCollaborator {
    /**
     * @member {string} [email] The email address of the user.
     */
    email?: string;
}
/**
 * @interface
 * An interface representing CollaboratorsArray.
 */
export interface CollaboratorsArray {
    /**
     * @member {string[]} [emails] The email address of the users.
     */
    emails?: string[];
}
/**
 * @interface
 * An interface representing ErrorResponse.
 * Error response when invoking an operation on the API.
 *
 */
export interface ErrorResponse {
    /**
     * @member {string} [errorType]
     */
    errorType?: string;
    /**
     * @property Describes unknown properties. The value of an unknown property
     * can be of "any" type.
     */
    [property: string]: any;
}
/**
 * @interface
 * An interface representing OperationError.
 * Operation error details when invoking an operation on the API.
 *
 */
export interface OperationError {
    /**
     * @member {string} [code]
     */
    code?: string;
    /**
     * @member {string} [message]
     */
    message?: string;
}
/**
 * @interface
 * An interface representing PrebuiltDomainItem.
 */
export interface PrebuiltDomainItem {
    /**
     * @member {string} [name]
     */
    name?: string;
    /**
     * @member {string} [description]
     */
    description?: string;
    /**
     * @member {string} [examples]
     */
    examples?: string;
}
/**
 * @interface
 * An interface representing PrebuiltDomain.
 * Prebuilt Domain.
 *
 */
export interface PrebuiltDomain {
    /**
     * @member {string} [name]
     */
    name?: string;
    /**
     * @member {string} [culture]
     */
    culture?: string;
    /**
     * @member {string} [description]
     */
    description?: string;
    /**
     * @member {string} [examples]
     */
    examples?: string;
    /**
     * @member {PrebuiltDomainItem[]} [intents]
     */
    intents?: PrebuiltDomainItem[];
    /**
     * @member {PrebuiltDomainItem[]} [entities]
     */
    entities?: PrebuiltDomainItem[];
}
/**
 * @interface
 * An interface representing EntityRoleCreateObject.
 * Object model for creating an entity role.
 *
 */
export interface EntityRoleCreateObject {
    /**
     * @member {string} [name] The entity role name.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing RegexModelCreateObject.
 * Model object for creating a regular expression entity model.
 *
 */
export interface RegexModelCreateObject {
    /**
     * @member {string} [regexPattern] The regular expression entity pattern.
     */
    regexPattern?: string;
    /**
     * @member {string} [name] The model name.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing PatternAnyModelCreateObject.
 * Model object for creating a Pattern.Any entity model.
 *
 */
export interface PatternAnyModelCreateObject {
    /**
     * @member {string} [name] The model name.
     */
    name?: string;
    /**
     * @member {string[]} [explicitList] The Pattern.Any explicit list.
     */
    explicitList?: string[];
}
/**
 * @interface
 * An interface representing ExplicitListItemCreateObject.
 * Object model for creating an explicit (exception) list item.
 *
 */
export interface ExplicitListItemCreateObject {
    /**
     * @member {string} [explicitListItem] The explicit list item.
     */
    explicitListItem?: string;
}
/**
 * @interface
 * An interface representing RegexModelUpdateObject.
 * Model object for updating a regular expression entity model.
 *
 */
export interface RegexModelUpdateObject {
    /**
     * @member {string} [regexPattern] The regular expression entity pattern.
     */
    regexPattern?: string;
    /**
     * @member {string} [name] The model name.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing PatternAnyModelUpdateObject.
 * Model object for updating a Pattern.Any entity model.
 *
 */
export interface PatternAnyModelUpdateObject {
    /**
     * @member {string} [name] The model name.
     */
    name?: string;
    /**
     * @member {string[]} [explicitList] The Pattern.Any explicit list.
     */
    explicitList?: string[];
}
/**
 * @interface
 * An interface representing EntityRoleUpdateObject.
 * Object model for updating an entity role.
 *
 */
export interface EntityRoleUpdateObject {
    /**
     * @member {string} [name] The entity role name.
     */
    name?: string;
}
/**
 * @interface
 * An interface representing ExplicitListItemUpdateObject.
 * Model object for updating an explicit (exception) list item.
 *
 */
export interface ExplicitListItemUpdateObject {
    /**
     * @member {string} [explicitListItem] The explicit list item.
     */
    explicitListItem?: string;
}
/**
 * @interface
 * An interface representing PatternRuleCreateObject.
 * Object model for creating a pattern
 *
 */
export interface PatternRuleCreateObject {
    /**
     * @member {string} [pattern] The pattern text.
     */
    pattern?: string;
    /**
     * @member {string} [intent] The intent's name which the pattern belongs to.
     */
    intent?: string;
}
/**
 * @interface
 * An interface representing PatternRuleUpdateObject.
 * Object model for updating a pattern.
 *
 */
export interface PatternRuleUpdateObject {
    /**
     * @member {string} [id] The pattern ID.
     */
    id?: string;
    /**
     * @member {string} [pattern] The pattern text.
     */
    pattern?: string;
    /**
     * @member {string} [intent] The intent's name which the pattern belongs to.
     */
    intent?: string;
}
/**
 * @interface
 * An interface representing RegexEntityExtractor.
 * Regular Expression Entity Extractor.
 *
 */
export interface RegexEntityExtractor {
    /**
     * @member {string} id The ID of the Entity Model.
     */
    id: string;
    /**
     * @member {string} [name] Name of the Entity Model.
     */
    name?: string;
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType9} readableType Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType: ReadableType9;
    /**
     * @member {EntityRole[]} [roles]
     */
    roles?: EntityRole[];
    /**
     * @member {string} [regexPattern] The Regular Expression entity pattern.
     */
    regexPattern?: string;
}
/**
 * @interface
 * An interface representing PatternAnyEntityExtractor.
 * Pattern.Any Entity Extractor.
 *
 */
export interface PatternAnyEntityExtractor {
    /**
     * @member {string} id The ID of the Entity Model.
     */
    id: string;
    /**
     * @member {string} [name] Name of the Entity Model.
     */
    name?: string;
    /**
     * @member {number} [typeId] The type ID of the Entity Model.
     */
    typeId?: number;
    /**
     * @member {ReadableType10} readableType Possible values include: 'Entity
     * Extractor', 'Hierarchical Entity Extractor', 'Hierarchical Child Entity
     * Extractor', 'Composite Entity Extractor', 'List Entity Extractor',
     * 'Prebuilt Entity Extractor', 'Intent Classifier', 'Pattern.Any Entity
     * Extractor', 'Closed List Entity Extractor', 'Regex Entity Extractor'
     */
    readableType: ReadableType10;
    /**
     * @member {EntityRole[]} [roles]
     */
    roles?: EntityRole[];
    /**
     * @member {ExplicitListItem[]} [explicitList]
     */
    explicitList?: ExplicitListItem[];
}
/**
 * @interface
 * An interface representing PatternRuleInfo.
 * Pattern rule
 *
 */
export interface PatternRuleInfo {
    /**
     * @member {string} [id] The pattern ID.
     */
    id?: string;
    /**
     * @member {string} [pattern] The pattern text.
     */
    pattern?: string;
    /**
     * @member {string} [intent] The intent's name where the pattern belongs to.
     */
    intent?: string;
}
/**
 * @interface
 * An interface representing LabelTextObject.
 * An object containing the example utterance's text.
 *
 */
export interface LabelTextObject {
    /**
     * @member {number} [id] The ID of the Label.
     */
    id?: number;
    /**
     * @member {string} [text] The text of the label.
     */
    text?: string;
}
/**
 * @interface
 * An interface representing AppVersionSettingObject.
 * Object model of an application version setting.
 *
 */
export interface AppVersionSettingObject {
    /**
     * @member {string} [name] The application version setting name.
     */
    name?: string;
    /**
     * @member {string} [value] The application version setting value.
     */
    value?: string;
}
/**
 * @interface
 * An interface representing AzureAccountInfoObject.
 * Defines the Azure account information object.
 *
 */
export interface AzureAccountInfoObject {
    /**
     * @member {string} azureSubscriptionId The id for the Azure subscription.
     */
    azureSubscriptionId: string;
    /**
     * @member {string} resourceGroup The Azure resource group name.
     */
    resourceGroup: string;
    /**
     * @member {string} accountName The Azure account name.
     */
    accountName: string;
}
/**
 * @interface
 * An interface representing HierarchicalChildModelUpdateObject.
 */
export interface HierarchicalChildModelUpdateObject {
    /**
     * @member {string} [name]
     */
    name?: string;
}
/**
 * @interface
 * An interface representing HierarchicalChildModelCreateObject.
 */
export interface HierarchicalChildModelCreateObject {
    /**
     * @member {string} [name]
     */
    name?: string;
}
/**
 * @interface
 * An interface representing CompositeChildModelCreateObject.
 */
export interface CompositeChildModelCreateObject {
    /**
     * @member {string} [name]
     */
    name?: string;
}
/**
 * @interface
 * An interface representing FeaturesListApplicationVersionPatternFeaturesOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface FeaturesListApplicationVersionPatternFeaturesOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing FeaturesListPhraseListsOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface FeaturesListPhraseListsOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing FeaturesListOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface FeaturesListOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing FeaturesUpdatePhraseListOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface FeaturesUpdatePhraseListOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {PhraselistUpdateObject} [phraselistUpdateObject] The new values
     * for: - Just a boolean called IsActive, in which case the status of the
     * feature will be changed. - Name, Pattern, Mode, and a boolean called
     * IsActive to update the feature.
     */
    phraselistUpdateObject?: PhraselistUpdateObject;
}
/**
 * @interface
 * An interface representing ExamplesListOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ExamplesListOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelListIntentsOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListIntentsOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelListEntitiesOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListEntitiesOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelListHierarchicalEntitiesOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListHierarchicalEntitiesOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelListCompositeEntitiesOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListCompositeEntitiesOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelListClosedListsOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListClosedListsOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelListPrebuiltsOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListPrebuiltsOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelListModelsOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListModelsOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelExamplesMethodOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelExamplesMethodOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelDeleteIntentOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelDeleteIntentOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {boolean} [deleteUtterances] If true, deletes the intent's example
     * utterances. If false, moves the example utterances to the None intent. The
     * default value is false. Default value: false .
     */
    deleteUtterances?: boolean;
}
/**
 * @interface
 * An interface representing ModelListIntentSuggestionsOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListIntentSuggestionsOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelListEntitySuggestionsOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListEntitySuggestionsOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelListRegexEntityInfosOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListRegexEntityInfosOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing ModelListPatternAnyEntityInfosOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface ModelListPatternAnyEntityInfosOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing AppsListOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface AppsListOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing AppsImportMethodOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface AppsImportMethodOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {string} [appName] The application name to create. If not
     * specified, the application name will be read from the imported object. If
     * the application name already exists, an error is returned.
     */
    appName?: string;
}
/**
 * @interface
 * An interface representing AppsDeleteMethodOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface AppsDeleteMethodOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {boolean} [force] A flag to indicate whether to force an
     * operation. Default value: false .
     */
    force?: boolean;
}
/**
 * @interface
 * An interface representing VersionsListOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface VersionsListOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing VersionsImportMethodOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface VersionsImportMethodOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {string} [versionId] The new versionId to import. If not
     * specified, the versionId will be read from the imported object.
     */
    versionId?: string;
}
/**
 * @interface
 * An interface representing PatternListPatternsOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface PatternListPatternsOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing PatternListIntentPatternsOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface PatternListIntentPatternsOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {number} [skip] The number of entries to skip. Default value is 0.
     * Default value: 0 .
     */
    skip?: number;
    /**
     * @member {number} [take] The number of entries to return. Maximum page size
     * is 500. Default is 100. Default value: 100 .
     */
    take?: number;
}
/**
 * @interface
 * An interface representing AzureAccountsAssignToAppOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface AzureAccountsAssignToAppOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {AzureAccountInfoObject} [azureAccountInfoObject] The Azure
     * account information object.
     */
    azureAccountInfoObject?: AzureAccountInfoObject;
}
/**
 * @interface
 * An interface representing AzureAccountsRemoveFromAppOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface AzureAccountsRemoveFromAppOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {AzureAccountInfoObject} [azureAccountInfoObject] The Azure
     * account information object.
     */
    azureAccountInfoObject?: AzureAccountInfoObject;
}
/**
 * Defines values for TrainingStatus.
 * Possible values include: 'NeedsTraining', 'InProgress', 'Trained'
 * @readonly
 * @enum {string}
 */
export declare type TrainingStatus = 'NeedsTraining' | 'InProgress' | 'Trained';
/**
 * Defines values for OperationStatusType.
 * Possible values include: 'Failed', 'FAILED', 'Success'
 * @readonly
 * @enum {string}
 */
export declare type OperationStatusType = 'Failed' | 'FAILED' | 'Success';
/**
 * Defines values for ReadableType.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Defines values for ReadableType1.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType1 = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Defines values for ReadableType2.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType2 = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Defines values for ReadableType3.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType3 = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Defines values for ReadableType4.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType4 = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Defines values for ReadableType5.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType5 = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Defines values for ReadableType6.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType6 = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Defines values for ReadableType7.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType7 = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Defines values for ReadableType8.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType8 = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Defines values for Status.
 * Possible values include: 'Queued', 'InProgress', 'UpToDate', 'Fail', 'Success'
 * @readonly
 * @enum {string}
 */
export declare type Status = 'Queued' | 'InProgress' | 'UpToDate' | 'Fail' | 'Success';
/**
 * Defines values for Status1.
 * Possible values include: 'Queued', 'InProgress', 'UpToDate', 'Fail', 'Success'
 * @readonly
 * @enum {string}
 */
export declare type Status1 = 'Queued' | 'InProgress' | 'UpToDate' | 'Fail' | 'Success';
/**
 * Defines values for ReadableType9.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType9 = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Defines values for ReadableType10.
 * Possible values include: 'Entity Extractor', 'Hierarchical Entity Extractor', 'Hierarchical
 * Child Entity Extractor', 'Composite Entity Extractor', 'List Entity Extractor', 'Prebuilt Entity
 * Extractor', 'Intent Classifier', 'Pattern.Any Entity Extractor', 'Closed List Entity Extractor',
 * 'Regex Entity Extractor'
 * @readonly
 * @enum {string}
 */
export declare type ReadableType10 = 'Entity Extractor' | 'Hierarchical Entity Extractor' | 'Hierarchical Child Entity Extractor' | 'Composite Entity Extractor' | 'List Entity Extractor' | 'Prebuilt Entity Extractor' | 'Intent Classifier' | 'Pattern.Any Entity Extractor' | 'Closed List Entity Extractor' | 'Regex Entity Extractor';
/**
 * Contains response data for the createPatternFeature operation.
 */
export declare type FeaturesCreatePatternFeatureResponse = {
    /**
     * The parsed response body.
     */
    body: number;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: number;
    };
};
/**
 * Contains response data for the listApplicationVersionPatternFeatures operation.
 */
export declare type FeaturesListApplicationVersionPatternFeaturesResponse = Array<PatternFeatureInfo> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PatternFeatureInfo[];
    };
};
/**
 * Contains response data for the addPhraseList operation.
 */
export declare type FeaturesAddPhraseListResponse = {
    /**
     * The parsed response body.
     */
    body: number;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: number;
    };
};
/**
 * Contains response data for the listPhraseLists operation.
 */
export declare type FeaturesListPhraseListsResponse = Array<PhraseListFeatureInfo> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PhraseListFeatureInfo[];
    };
};
/**
 * Contains response data for the list operation.
 */
export declare type FeaturesListResponse = FeaturesResponseObject & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: FeaturesResponseObject;
    };
};
/**
 * Contains response data for the getPatternFeatureInfo operation.
 */
export declare type FeaturesGetPatternFeatureInfoResponse = PatternFeatureInfo & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PatternFeatureInfo;
    };
};
/**
 * Contains response data for the updatePatternFeature operation.
 */
export declare type FeaturesUpdatePatternFeatureResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deletePatternFeature operation.
 */
export declare type FeaturesDeletePatternFeatureResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getPhraseList operation.
 */
export declare type FeaturesGetPhraseListResponse = PhraseListFeatureInfo & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PhraseListFeatureInfo;
    };
};
/**
 * Contains response data for the updatePhraseList operation.
 */
export declare type FeaturesUpdatePhraseListResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deletePhraseList operation.
 */
export declare type FeaturesDeletePhraseListResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the add operation.
 */
export declare type ExamplesAddResponse = LabelExampleResponse & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: LabelExampleResponse;
    };
};
/**
 * Contains response data for the batch operation.
 */
export declare type ExamplesBatchResponse = Array<BatchLabelExample> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: BatchLabelExample[];
    };
};
/**
 * Contains response data for the list operation.
 */
export declare type ExamplesListResponse = Array<LabeledUtterance> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: LabeledUtterance[];
    };
};
/**
 * Contains response data for the deleteMethod operation.
 */
export declare type ExamplesDeleteMethodResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the addIntent operation.
 */
export declare type ModelAddIntentResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listIntents operation.
 */
export declare type ModelListIntentsResponse = Array<IntentClassifier> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: IntentClassifier[];
    };
};
/**
 * Contains response data for the addEntity operation.
 */
export declare type ModelAddEntityResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listEntities operation.
 */
export declare type ModelListEntitiesResponse = Array<EntityExtractor> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityExtractor[];
    };
};
/**
 * Contains response data for the addHierarchicalEntity operation.
 */
export declare type ModelAddHierarchicalEntityResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listHierarchicalEntities operation.
 */
export declare type ModelListHierarchicalEntitiesResponse = Array<HierarchicalEntityExtractor> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: HierarchicalEntityExtractor[];
    };
};
/**
 * Contains response data for the addCompositeEntity operation.
 */
export declare type ModelAddCompositeEntityResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listCompositeEntities operation.
 */
export declare type ModelListCompositeEntitiesResponse = Array<CompositeEntityExtractor> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: CompositeEntityExtractor[];
    };
};
/**
 * Contains response data for the listClosedLists operation.
 */
export declare type ModelListClosedListsResponse = Array<ClosedListEntityExtractor> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ClosedListEntityExtractor[];
    };
};
/**
 * Contains response data for the addClosedList operation.
 */
export declare type ModelAddClosedListResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the addPrebuilt operation.
 */
export declare type ModelAddPrebuiltResponse = Array<PrebuiltEntityExtractor> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PrebuiltEntityExtractor[];
    };
};
/**
 * Contains response data for the listPrebuilts operation.
 */
export declare type ModelListPrebuiltsResponse = Array<PrebuiltEntityExtractor> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PrebuiltEntityExtractor[];
    };
};
/**
 * Contains response data for the listPrebuiltEntities operation.
 */
export declare type ModelListPrebuiltEntitiesResponse = Array<AvailablePrebuiltEntityModel> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: AvailablePrebuiltEntityModel[];
    };
};
/**
 * Contains response data for the listModels operation.
 */
export declare type ModelListModelsResponse = Array<ModelInfoResponse> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ModelInfoResponse[];
    };
};
/**
 * Contains response data for the examplesMethod operation.
 */
export declare type ModelExamplesMethodResponse = Array<LabelTextObject> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: LabelTextObject[];
    };
};
/**
 * Contains response data for the getIntent operation.
 */
export declare type ModelGetIntentResponse = IntentClassifier & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: IntentClassifier;
    };
};
/**
 * Contains response data for the updateIntent operation.
 */
export declare type ModelUpdateIntentResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteIntent operation.
 */
export declare type ModelDeleteIntentResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getEntity operation.
 */
export declare type ModelGetEntityResponse = EntityExtractor & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityExtractor;
    };
};
/**
 * Contains response data for the updateEntity operation.
 */
export declare type ModelUpdateEntityResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteEntity operation.
 */
export declare type ModelDeleteEntityResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getHierarchicalEntity operation.
 */
export declare type ModelGetHierarchicalEntityResponse = HierarchicalEntityExtractor & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: HierarchicalEntityExtractor;
    };
};
/**
 * Contains response data for the updateHierarchicalEntity operation.
 */
export declare type ModelUpdateHierarchicalEntityResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteHierarchicalEntity operation.
 */
export declare type ModelDeleteHierarchicalEntityResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getCompositeEntity operation.
 */
export declare type ModelGetCompositeEntityResponse = CompositeEntityExtractor & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: CompositeEntityExtractor;
    };
};
/**
 * Contains response data for the updateCompositeEntity operation.
 */
export declare type ModelUpdateCompositeEntityResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteCompositeEntity operation.
 */
export declare type ModelDeleteCompositeEntityResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getClosedList operation.
 */
export declare type ModelGetClosedListResponse = ClosedListEntityExtractor & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ClosedListEntityExtractor;
    };
};
/**
 * Contains response data for the updateClosedList operation.
 */
export declare type ModelUpdateClosedListResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the patchClosedList operation.
 */
export declare type ModelPatchClosedListResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteClosedList operation.
 */
export declare type ModelDeleteClosedListResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getPrebuilt operation.
 */
export declare type ModelGetPrebuiltResponse = PrebuiltEntityExtractor & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PrebuiltEntityExtractor;
    };
};
/**
 * Contains response data for the deletePrebuilt operation.
 */
export declare type ModelDeletePrebuiltResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteSubList operation.
 */
export declare type ModelDeleteSubListResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the updateSubList operation.
 */
export declare type ModelUpdateSubListResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the listIntentSuggestions operation.
 */
export declare type ModelListIntentSuggestionsResponse = Array<IntentsSuggestionExample> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: IntentsSuggestionExample[];
    };
};
/**
 * Contains response data for the listEntitySuggestions operation.
 */
export declare type ModelListEntitySuggestionsResponse = Array<EntitiesSuggestionExample> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntitiesSuggestionExample[];
    };
};
/**
 * Contains response data for the addSubList operation.
 */
export declare type ModelAddSubListResponse = {
    /**
     * The parsed response body.
     */
    body: number;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: number;
    };
};
/**
 * Contains response data for the addCustomPrebuiltDomain operation.
 */
export declare type ModelAddCustomPrebuiltDomainResponse = Array<string> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string[];
    };
};
/**
 * Contains response data for the addCustomPrebuiltIntent operation.
 */
export declare type ModelAddCustomPrebuiltIntentResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listCustomPrebuiltIntents operation.
 */
export declare type ModelListCustomPrebuiltIntentsResponse = Array<IntentClassifier> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: IntentClassifier[];
    };
};
/**
 * Contains response data for the addCustomPrebuiltEntity operation.
 */
export declare type ModelAddCustomPrebuiltEntityResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listCustomPrebuiltEntities operation.
 */
export declare type ModelListCustomPrebuiltEntitiesResponse = Array<EntityExtractor> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityExtractor[];
    };
};
/**
 * Contains response data for the listCustomPrebuiltModels operation.
 */
export declare type ModelListCustomPrebuiltModelsResponse = Array<CustomPrebuiltModel> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: CustomPrebuiltModel[];
    };
};
/**
 * Contains response data for the deleteCustomPrebuiltDomain operation.
 */
export declare type ModelDeleteCustomPrebuiltDomainResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getHierarchicalEntityChild operation.
 */
export declare type ModelGetHierarchicalEntityChildResponse = HierarchicalChildEntity & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: HierarchicalChildEntity;
    };
};
/**
 * Contains response data for the updateHierarchicalEntityChild operation.
 */
export declare type ModelUpdateHierarchicalEntityChildResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteHierarchicalEntityChild operation.
 */
export declare type ModelDeleteHierarchicalEntityChildResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the addHierarchicalEntityChild operation.
 */
export declare type ModelAddHierarchicalEntityChildResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the addCompositeEntityChild operation.
 */
export declare type ModelAddCompositeEntityChildResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the deleteCompositeEntityChild operation.
 */
export declare type ModelDeleteCompositeEntityChildResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the listRegexEntityInfos operation.
 */
export declare type ModelListRegexEntityInfosResponse = Array<RegexEntityExtractor> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RegexEntityExtractor[];
    };
};
/**
 * Contains response data for the createRegexEntityModel operation.
 */
export declare type ModelCreateRegexEntityModelResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listPatternAnyEntityInfos operation.
 */
export declare type ModelListPatternAnyEntityInfosResponse = Array<PatternAnyEntityExtractor> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PatternAnyEntityExtractor[];
    };
};
/**
 * Contains response data for the createPatternAnyEntityModel operation.
 */
export declare type ModelCreatePatternAnyEntityModelResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listEntityRoles operation.
 */
export declare type ModelListEntityRolesResponse = Array<EntityRole> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole[];
    };
};
/**
 * Contains response data for the createEntityRole operation.
 */
export declare type ModelCreateEntityRoleResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listPrebuiltEntityRoles operation.
 */
export declare type ModelListPrebuiltEntityRolesResponse = Array<EntityRole> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole[];
    };
};
/**
 * Contains response data for the createPrebuiltEntityRole operation.
 */
export declare type ModelCreatePrebuiltEntityRoleResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listClosedListEntityRoles operation.
 */
export declare type ModelListClosedListEntityRolesResponse = Array<EntityRole> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole[];
    };
};
/**
 * Contains response data for the createClosedListEntityRole operation.
 */
export declare type ModelCreateClosedListEntityRoleResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listRegexEntityRoles operation.
 */
export declare type ModelListRegexEntityRolesResponse = Array<EntityRole> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole[];
    };
};
/**
 * Contains response data for the createRegexEntityRole operation.
 */
export declare type ModelCreateRegexEntityRoleResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listCompositeEntityRoles operation.
 */
export declare type ModelListCompositeEntityRolesResponse = Array<EntityRole> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole[];
    };
};
/**
 * Contains response data for the createCompositeEntityRole operation.
 */
export declare type ModelCreateCompositeEntityRoleResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listPatternAnyEntityRoles operation.
 */
export declare type ModelListPatternAnyEntityRolesResponse = Array<EntityRole> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole[];
    };
};
/**
 * Contains response data for the createPatternAnyEntityRole operation.
 */
export declare type ModelCreatePatternAnyEntityRoleResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listHierarchicalEntityRoles operation.
 */
export declare type ModelListHierarchicalEntityRolesResponse = Array<EntityRole> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole[];
    };
};
/**
 * Contains response data for the createHierarchicalEntityRole operation.
 */
export declare type ModelCreateHierarchicalEntityRoleResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listCustomPrebuiltEntityRoles operation.
 */
export declare type ModelListCustomPrebuiltEntityRolesResponse = Array<EntityRole> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole[];
    };
};
/**
 * Contains response data for the createCustomPrebuiltEntityRole operation.
 */
export declare type ModelCreateCustomPrebuiltEntityRoleResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the getExplicitList operation.
 */
export declare type ModelGetExplicitListResponse = Array<ExplicitListItem> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ExplicitListItem[];
    };
};
/**
 * Contains response data for the addExplicitListItem operation.
 */
export declare type ModelAddExplicitListItemResponse = {
    /**
     * The parsed response body.
     */
    body: number;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: number;
    };
};
/**
 * Contains response data for the getRegexEntityEntityInfo operation.
 */
export declare type ModelGetRegexEntityEntityInfoResponse = RegexEntityExtractor & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RegexEntityExtractor;
    };
};
/**
 * Contains response data for the updateRegexEntityModel operation.
 */
export declare type ModelUpdateRegexEntityModelResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteRegexEntityModel operation.
 */
export declare type ModelDeleteRegexEntityModelResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getPatternAnyEntityInfo operation.
 */
export declare type ModelGetPatternAnyEntityInfoResponse = PatternAnyEntityExtractor & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PatternAnyEntityExtractor;
    };
};
/**
 * Contains response data for the updatePatternAnyEntityModel operation.
 */
export declare type ModelUpdatePatternAnyEntityModelResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deletePatternAnyEntityModel operation.
 */
export declare type ModelDeletePatternAnyEntityModelResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getEntityRole operation.
 */
export declare type ModelGetEntityRoleResponse = EntityRole & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole;
    };
};
/**
 * Contains response data for the updateEntityRole operation.
 */
export declare type ModelUpdateEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteEntityRole operation.
 */
export declare type ModelDeleteEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getPrebuiltEntityRole operation.
 */
export declare type ModelGetPrebuiltEntityRoleResponse = EntityRole & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole;
    };
};
/**
 * Contains response data for the updatePrebuiltEntityRole operation.
 */
export declare type ModelUpdatePrebuiltEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deletePrebuiltEntityRole operation.
 */
export declare type ModelDeletePrebuiltEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getClosedListEntityRole operation.
 */
export declare type ModelGetClosedListEntityRoleResponse = EntityRole & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole;
    };
};
/**
 * Contains response data for the updateClosedListEntityRole operation.
 */
export declare type ModelUpdateClosedListEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteClosedListEntityRole operation.
 */
export declare type ModelDeleteClosedListEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getRegexEntityRole operation.
 */
export declare type ModelGetRegexEntityRoleResponse = EntityRole & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole;
    };
};
/**
 * Contains response data for the updateRegexEntityRole operation.
 */
export declare type ModelUpdateRegexEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteRegexEntityRole operation.
 */
export declare type ModelDeleteRegexEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getCompositeEntityRole operation.
 */
export declare type ModelGetCompositeEntityRoleResponse = EntityRole & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole;
    };
};
/**
 * Contains response data for the updateCompositeEntityRole operation.
 */
export declare type ModelUpdateCompositeEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteCompositeEntityRole operation.
 */
export declare type ModelDeleteCompositeEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getPatternAnyEntityRole operation.
 */
export declare type ModelGetPatternAnyEntityRoleResponse = EntityRole & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole;
    };
};
/**
 * Contains response data for the updatePatternAnyEntityRole operation.
 */
export declare type ModelUpdatePatternAnyEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deletePatternAnyEntityRole operation.
 */
export declare type ModelDeletePatternAnyEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getHierarchicalEntityRole operation.
 */
export declare type ModelGetHierarchicalEntityRoleResponse = EntityRole & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole;
    };
};
/**
 * Contains response data for the updateHierarchicalEntityRole operation.
 */
export declare type ModelUpdateHierarchicalEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteHierarchicalEntityRole operation.
 */
export declare type ModelDeleteHierarchicalEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getCustomEntityRole operation.
 */
export declare type ModelGetCustomEntityRoleResponse = EntityRole & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EntityRole;
    };
};
/**
 * Contains response data for the updateCustomPrebuiltEntityRole operation.
 */
export declare type ModelUpdateCustomPrebuiltEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteCustomEntityRole operation.
 */
export declare type ModelDeleteCustomEntityRoleResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getExplicitListItem operation.
 */
export declare type ModelGetExplicitListItemResponse = ExplicitListItem & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ExplicitListItem;
    };
};
/**
 * Contains response data for the updateExplicitListItem operation.
 */
export declare type ModelUpdateExplicitListItemResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteExplicitListItem operation.
 */
export declare type ModelDeleteExplicitListItemResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the add operation.
 */
export declare type AppsAddResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the list operation.
 */
export declare type AppsListResponse = Array<ApplicationInfoResponse> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ApplicationInfoResponse[];
    };
};
/**
 * Contains response data for the importMethod operation.
 */
export declare type AppsImportMethodResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listCortanaEndpoints operation.
 */
export declare type AppsListCortanaEndpointsResponse = PersonalAssistantsResponse & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PersonalAssistantsResponse;
    };
};
/**
 * Contains response data for the listDomains operation.
 */
export declare type AppsListDomainsResponse = Array<string> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string[];
    };
};
/**
 * Contains response data for the listUsageScenarios operation.
 */
export declare type AppsListUsageScenariosResponse = Array<string> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string[];
    };
};
/**
 * Contains response data for the listSupportedCultures operation.
 */
export declare type AppsListSupportedCulturesResponse = Array<AvailableCulture> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: AvailableCulture[];
    };
};
/**
 * Contains response data for the downloadQueryLogs operation.
 */
export declare type AppsDownloadQueryLogsResponse = {
    /**
     * BROWSER ONLY
     *
     * The response body as a browser Blob.
     * Always undefined in node.js.
     */
    blobBody?: Promise<Blob>;
    /**
     * NODEJS ONLY
     *
     * The response body as a node.js Readable stream.
     * Always undefined in the browser.
     */
    readableStreamBody?: NodeJS.ReadableStream;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse;
};
/**
 * Contains response data for the get operation.
 */
export declare type AppsGetResponse = ApplicationInfoResponse & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ApplicationInfoResponse;
    };
};
/**
 * Contains response data for the update operation.
 */
export declare type AppsUpdateResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteMethod operation.
 */
export declare type AppsDeleteMethodResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the publish operation.
 */
export declare type AppsPublishResponse = ProductionOrStagingEndpointInfo & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ProductionOrStagingEndpointInfo;
    };
};
/**
 * Contains response data for the getSettings operation.
 */
export declare type AppsGetSettingsResponse = ApplicationSettings & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ApplicationSettings;
    };
};
/**
 * Contains response data for the updateSettings operation.
 */
export declare type AppsUpdateSettingsResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getPublishSettings operation.
 */
export declare type AppsGetPublishSettingsResponse = PublishSettings & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PublishSettings;
    };
};
/**
 * Contains response data for the updatePublishSettings operation.
 */
export declare type AppsUpdatePublishSettingsResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the listEndpoints operation.
 */
export declare type AppsListEndpointsResponse = {
    /**
     * The response body properties.
     */
    [propertyName: string]: string;
} & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: {
            [propertyName: string]: string;
        };
    };
};
/**
 * Contains response data for the listAvailableCustomPrebuiltDomains operation.
 */
export declare type AppsListAvailableCustomPrebuiltDomainsResponse = Array<PrebuiltDomain> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PrebuiltDomain[];
    };
};
/**
 * Contains response data for the addCustomPrebuiltDomain operation.
 */
export declare type AppsAddCustomPrebuiltDomainResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the listAvailableCustomPrebuiltDomainsForCulture operation.
 */
export declare type AppsListAvailableCustomPrebuiltDomainsForCultureResponse = Array<PrebuiltDomain> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PrebuiltDomain[];
    };
};
/**
 * Contains response data for the packagePublishedApplicationAsGzip operation.
 */
export declare type AppsPackagePublishedApplicationAsGzipResponse = {
    /**
     * BROWSER ONLY
     *
     * The response body as a browser Blob.
     * Always undefined in node.js.
     */
    blobBody?: Promise<Blob>;
    /**
     * NODEJS ONLY
     *
     * The response body as a node.js Readable stream.
     * Always undefined in the browser.
     */
    readableStreamBody?: NodeJS.ReadableStream;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse;
};
/**
 * Contains response data for the packageTrainedApplicationAsGzip operation.
 */
export declare type AppsPackageTrainedApplicationAsGzipResponse = {
    /**
     * BROWSER ONLY
     *
     * The response body as a browser Blob.
     * Always undefined in node.js.
     */
    blobBody?: Promise<Blob>;
    /**
     * NODEJS ONLY
     *
     * The response body as a node.js Readable stream.
     * Always undefined in the browser.
     */
    readableStreamBody?: NodeJS.ReadableStream;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse;
};
/**
 * Contains response data for the clone operation.
 */
export declare type VersionsCloneResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the list operation.
 */
export declare type VersionsListResponse = Array<VersionInfo> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: VersionInfo[];
    };
};
/**
 * Contains response data for the get operation.
 */
export declare type VersionsGetResponse = VersionInfo & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: VersionInfo;
    };
};
/**
 * Contains response data for the update operation.
 */
export declare type VersionsUpdateResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteMethod operation.
 */
export declare type VersionsDeleteMethodResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the exportMethod operation.
 */
export declare type VersionsExportMethodResponse = LuisApp & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: LuisApp;
    };
};
/**
 * Contains response data for the importMethod operation.
 */
export declare type VersionsImportMethodResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the deleteUnlabelledUtterance operation.
 */
export declare type VersionsDeleteUnlabelledUtteranceResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the trainVersion operation.
 */
export declare type TrainTrainVersionResponse = EnqueueTrainingResponse & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: EnqueueTrainingResponse;
    };
};
/**
 * Contains response data for the getStatus operation.
 */
export declare type TrainGetStatusResponse = Array<ModelTrainingInfo> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ModelTrainingInfo[];
    };
};
/**
 * Contains response data for the list operation.
 */
export declare type PermissionsListResponse = UserAccessList & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: UserAccessList;
    };
};
/**
 * Contains response data for the add operation.
 */
export declare type PermissionsAddResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the deleteMethod operation.
 */
export declare type PermissionsDeleteMethodResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the update operation.
 */
export declare type PermissionsUpdateResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the addPattern operation.
 */
export declare type PatternAddPatternResponse = PatternRuleInfo & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PatternRuleInfo;
    };
};
/**
 * Contains response data for the listPatterns operation.
 */
export declare type PatternListPatternsResponse = Array<PatternRuleInfo> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PatternRuleInfo[];
    };
};
/**
 * Contains response data for the updatePatterns operation.
 */
export declare type PatternUpdatePatternsResponse = Array<PatternRuleInfo> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PatternRuleInfo[];
    };
};
/**
 * Contains response data for the batchAddPatterns operation.
 */
export declare type PatternBatchAddPatternsResponse = Array<PatternRuleInfo> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PatternRuleInfo[];
    };
};
/**
 * Contains response data for the deletePatterns operation.
 */
export declare type PatternDeletePatternsResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the updatePattern operation.
 */
export declare type PatternUpdatePatternResponse = PatternRuleInfo & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PatternRuleInfo;
    };
};
/**
 * Contains response data for the deletePattern operation.
 */
export declare type PatternDeletePatternResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the listIntentPatterns operation.
 */
export declare type PatternListIntentPatternsResponse = Array<PatternRuleInfo> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PatternRuleInfo[];
    };
};
/**
 * Contains response data for the list operation.
 */
export declare type SettingsListResponse = Array<AppVersionSettingObject> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: AppVersionSettingObject[];
    };
};
/**
 * Contains response data for the update operation.
 */
export declare type SettingsUpdateResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the assignToApp operation.
 */
export declare type AzureAccountsAssignToAppResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the getAssigned operation.
 */
export declare type AzureAccountsGetAssignedResponse = Array<AzureAccountInfoObject> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: AzureAccountInfoObject[];
    };
};
/**
 * Contains response data for the removeFromApp operation.
 */
export declare type AzureAccountsRemoveFromAppResponse = OperationStatus & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: OperationStatus;
    };
};
/**
 * Contains response data for the listUserLUISAccounts operation.
 */
export declare type AzureAccountsListUserLUISAccountsResponse = Array<AzureAccountInfoObject> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: AzureAccountInfoObject[];
    };
};
