import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { LuisAuthoringContext } from "../luisAuthoringContext";
/** Class representing a Settings. */
export declare class Settings {
    private readonly client;
    /**
     * Create a Settings.
     * @param {LuisAuthoringContext} client Reference to the service client.
     */
    constructor(client: LuisAuthoringContext);
    /**
     * Gets the settings in a version of the application.
     * @param appId The application ID.
     * @param versionId The version ID.
     * @param [options] The optional parameters
     * @returns Promise<Models.SettingsListResponse>
     */
    list(appId: string, versionId: string, options?: msRest.RequestOptionsBase): Promise<Models.SettingsListResponse>;
    /**
     * @param appId The application ID.
     * @param versionId The version ID.
     * @param callback The callback
     */
    list(appId: string, versionId: string, callback: msRest.ServiceCallback<Models.AppVersionSettingObject[]>): void;
    /**
     * @param appId The application ID.
     * @param versionId The version ID.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(appId: string, versionId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AppVersionSettingObject[]>): void;
    /**
     * Updates the settings in a version of the application.
     * @param appId The application ID.
     * @param versionId The version ID.
     * @param listOfAppVersionSettingObject A list of the updated application version settings.
     * @param [options] The optional parameters
     * @returns Promise<Models.SettingsUpdateResponse>
     */
    update(appId: string, versionId: string, listOfAppVersionSettingObject: Models.AppVersionSettingObject[], options?: msRest.RequestOptionsBase): Promise<Models.SettingsUpdateResponse>;
    /**
     * @param appId The application ID.
     * @param versionId The version ID.
     * @param listOfAppVersionSettingObject A list of the updated application version settings.
     * @param callback The callback
     */
    update(appId: string, versionId: string, listOfAppVersionSettingObject: Models.AppVersionSettingObject[], callback: msRest.ServiceCallback<Models.OperationStatus>): void;
    /**
     * @param appId The application ID.
     * @param versionId The version ID.
     * @param listOfAppVersionSettingObject A list of the updated application version settings.
     * @param options The optional parameters
     * @param callback The callback
     */
    update(appId: string, versionId: string, listOfAppVersionSettingObject: Models.AppVersionSettingObject[], options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.OperationStatus>): void;
}
